@@ -2,7 +2,8 @@ from scNodes.core import config as cfg
 import imgui
 import time
 import datetime
-from scNodes.core.dataset import *
+from scNodes.core.datatypes import *
+import matplotlib.pyplot as plt
 from scNodes.core import settings
 from joblib import Parallel, delayed
 from joblib.externals.loky import set_loky_pickler
@@ -12,6 +13,7 @@ set_loky_pickler("dill")
 class Node:
     title = "NullNode"
     group = "Ungrouped"
+    compatibility = "not versioned"
     colour = (1.0, 1.0, 1.0, 1.0)
     id_generator = count(0)
     size = 200
@@ -167,7 +169,9 @@ class Node:
         ## Node context_menu:
         if imgui.begin_popup_context_window():
             self.keep_active = cfg.focused_node == self
+            imgui.push_style_var(imgui.STYLE_FRAME_PADDING, (0, 0))
             _changed, self.keep_active = imgui.checkbox("Focus node", self.keep_active)
+            imgui.pop_style_var(1)
             if _changed:
                 if self.keep_active:
                     cfg.set_active_node(self, True)
@@ -234,16 +238,11 @@ class Node:
             # Draw STOP button
             origin = [window_position[0] + Node.PLAY_BUTTON_SIZE / 2.0,
                       window_position[1] + Node.PLAY_BUTTON_SIZE / 2.0]
-            p1 = (-1.0 * Node.PLAY_BUTTON_ICON_SIZE, 1.5 * Node.PLAY_BUTTON_ICON_SIZE)
-            p2 = (-1.0 * Node.PLAY_BUTTON_ICON_SIZE, -1.5 * Node.PLAY_BUTTON_ICON_SIZE)
-            draw_list.add_polyline([(p1[0] + origin[0], p1[1] + origin[1]),
-                                    (p2[0] + origin[0], p2[1] + origin[1])], imgui.get_color_u32_rgba(*Node.PLAY_BUTTON_ICON_COLOUR), False, Node.PLAY_BUTTON_ICON_LINEWIDTH / 2.0)
-            p1 = (1.0 * Node.PLAY_BUTTON_ICON_SIZE, 1.5 * Node.PLAY_BUTTON_ICON_SIZE)
-            p2 = (1.0 * Node.PLAY_BUTTON_ICON_SIZE, -1.5 * Node.PLAY_BUTTON_ICON_SIZE)
-            draw_list.add_polyline([(p1[0] + origin[0], p1[1] + origin[1]),
-                                    (p2[0] + origin[0], p2[1] + origin[1])],
-                                   imgui.get_color_u32_rgba(*Node.PLAY_BUTTON_ICON_COLOUR), False,
-                                   Node.PLAY_BUTTON_ICON_LINEWIDTH / 2.0)
+            x_min = origin[0] - Node.PLAY_BUTTON_ICON_SIZE * 1.51
+            x_max = origin[0] + Node.PLAY_BUTTON_ICON_SIZE * 1.51
+            y_min = origin[1] - Node.PLAY_BUTTON_ICON_SIZE * 1.51
+            y_max = origin[1] + Node.PLAY_BUTTON_ICON_SIZE * 1.51
+            draw_list.add_rect_filled(x_min, y_min, x_max, y_max, imgui.get_color_u32_rgba(*Node.PLAY_BUTTON_ICON_COLOUR))
         else:
             # Draw PLAY button
             origin = [window_position[0] + Node.PLAY_BUTTON_SIZE / 2.0,
@@ -324,7 +323,8 @@ class Node:
         self.use_roi = node_dict["use_roi"]
         self.roi = node_dict["roi"]
         self.lut = node_dict["lut"]
-        self.params = node_dict["params"]
+        for key in node_dict["params"]:
+            self.params[key] = node_dict["params"][key]
         self.connectable_attributes = dict()
         for attribute_dict in node_dict["attributes"]:
             attribute = ConnectableAttribute(attribute_dict["type"], attribute_dict["direction"], self, attribute_dict["allowed_partner_types"])
@@ -341,7 +341,7 @@ class Node:
 
     @staticmethod
     def gen_temp_dir_name():
-        return str(datetime.datetime.now().strftime('%Y%m%d%H%M%S%f'))
+        return "_SRNTEMP"+str(datetime.datetime.now().strftime('%Y%m%d%H%M%S%f'))
 
     @staticmethod
     def tooltip(text):
@@ -372,17 +372,14 @@ class Node:
         :return: node: node with type TYPE_LOAD_DATA
         """
         def get_any_incoming_node(_node):
-            print(_node)
             for attribute in _node.connectable_attributes.values():
                 if attribute.direction == ConnectableAttribute.INPUT:
-                    print("input")
                     return attribute.get_incoming_node()
 
         if node.NODE_IS_DATA_SOURCE:
             return node
         try:
             source = get_any_incoming_node(node)
-            print(source)
             while not isinstance(source, NullNode):
                 if source.NODE_IS_DATA_SOURCE:
                     return source
