@@ -1,7 +1,6 @@
 from scNodes.core.node import *
 from scNodes.core import particlefitting as pfit
 
-
 def create():
     return ParticleFittingNode()
 
@@ -12,7 +11,7 @@ class ParticleFittingNode(Node):
     colour = (230 / 255, 98 / 255, 13 / 255, 1.0)
     size = 300
     sortid = 1001
-    RANGE_OPTIONS = ["All frames", "Current frame only", "Custom range"]
+    RANGE_OPTIONS = ["All frames", "Current frame only", "Custom range", "Random subset"]
     ESTIMATORS = ["Least squares (GPU)", "Maximum likelihood (GPU)", "No estimator (CPU)"]
     PSFS = ["Gaussian", "Elliptical Gaussian"]
 
@@ -27,7 +26,9 @@ class ParticleFittingNode(Node):
         self.params["range_option"] = 1
         self.params["range_min"] = 0
         self.params["range_max"] = 1
+        self.params["subset_size"] = 50
         self.params["estimator"] = 1
+        self.params["psf"] = 0
         self.params["crop_radius"] = 3
         self.params["initial_sigma"] = 1.6
         self.fitting = False
@@ -47,6 +48,7 @@ class ParticleFittingNode(Node):
         self.params["offset_max"] = -1.0
 
         self.params["custom_bounds"] = False
+        self.params["photons_per_count"] = 0.45
 
     def render(self):
         if super().render_start():
@@ -61,8 +63,10 @@ class ParticleFittingNode(Node):
             imgui.spacing()
             imgui.separator()
             imgui.spacing()
-            imgui.set_next_item_width(180)
+            imgui.set_next_item_width(200)
             _c, self.params["estimator"] = imgui.combo("Estimator", self.params["estimator"], ParticleFittingNode.ESTIMATORS)
+            imgui.set_next_item_width(148)
+            _c, self.params["psf"] = imgui.combo("PSF", self.params["psf"], ParticleFittingNode.PSFS)
             if self.params["estimator"] in [0, 1]:
                 imgui.same_line()
                 imgui.button("?", 19, 19)
@@ -86,6 +90,9 @@ class ParticleFittingNode(Node):
                 _c, (self.params["range_min"], self.params["range_max"]) = imgui.input_int2('[start, stop) index', self.params["range_min"],
                                                                         self.params["range_max"])
                 imgui.pop_item_width()
+            if self.params["range_option"] == 3:
+                imgui.push_item_width(80)
+                _c, self.params["subset_size"] = imgui.input_int("# frames", self.params["subset_size"], 0, 0)
             imgui.spacing()
             if self.fitting:
                 self.progress_bar(self.n_fitted / self.n_to_fit)
@@ -101,10 +108,9 @@ class ParticleFittingNode(Node):
                 self.fitting = False
                 self.particle_data.bake()
 
-            ## TODO: add camera offset and ADU per photon (to LOAD DATASET?)
             if not self.particle_data.empty:
                 imgui.text("Reconstruction info")
-                imgui.text(f"particles: {len(self.particle_data.particles)}")
+                imgui.text(f"particles: {self.particle_data.n_particles}")
                 if not self.fitting:
                     imgui.text(f"x range: {self.particle_data.x_min / 1000.0:.1f} to {self.particle_data.x_max / 1000.0:.1f} um")
                     imgui.text(f"y range: {self.particle_data.y_min / 1000.0:.1f} to {self.particle_data.y_max / 1000.0:.1f} um")
@@ -116,6 +122,8 @@ class ParticleFittingNode(Node):
             super().render_end()
 
     def render_advanced(self):
+        imgui.set_next_item_width(80)
+        _c, self.params["photons_per_count"] = imgui.input_float("photons per count", self.params["photons_per_count"], 0, 0, "%.2f")
         _c, self.params["custom_bounds"] = imgui.checkbox("Use custom parameter bounds", self.params["custom_bounds"])
         Node.tooltip("Edit the bounds for particle parameters intensity, sigma, and offset.")
         if self.params["custom_bounds"]:
@@ -154,15 +162,16 @@ class ParticleFittingNode(Node):
             self.particle_data.set_reconstruction_roi(np.asarray(dataset_source.dataset.reconstruction_roi) * dataset_source.pixel_size)
             self.fitting = True
             self.frames_to_fit = list()
+            dataset = dataset_source.dataset
+            n_frames = dataset.n_frames
             if self.params["range_option"] == 0:
-                dataset = dataset_source.dataset
-                n_frames = dataset.n_frames
                 self.frames_to_fit = list(range(0, n_frames))
             elif self.params["range_option"] == 2:
                 self.frames_to_fit = list(range(self.params["range_min"], self.params["range_max"]))
             elif self.params["range_option"] == 1:
-                dataset = dataset_source.dataset
                 self.frames_to_fit = [dataset.current_frame]
+            elif self.params["range_option"] == 3:
+                self.frames_to_fit = np.random.choice(n_frames, size=min([n_frames, self.params["subset_size"]]), replace=False).tolist()
             self.n_to_fit = len(self.frames_to_fit)
             self.n_fitted = 0
         except Exception as e:
@@ -201,19 +210,43 @@ class ParticleFittingNode(Node):
                 return frame
             particles = list()
             if self.params["estimator"] in [0, 1]:
-                particles = pfit.frame_to_particles(frame, self.params["initial_sigma"], self.params["estimator"], self.params["crop_radius"], constraints=[self.params["intensity_min"], self.params["intensity_max"], -1, -1, -1, -1, self.params["sigma_min"], self.params["sigma_max"], self.params["offset_min"], self.params["offset_max"]])
+                if self.params["psf"] == 0:
+                    particles = pfit.frame_to_particles(frame, self.params["initial_sigma"], self.params["estimator"], self.params["crop_radius"],
+                                                        constraints=[self.params["intensity_min"],
+                                                                     self.params["intensity_max"], -1, -1, -1, -1,
+                                                                     self.params["sigma_min"],
+                                                                     self.params["sigma_max"],
+                                                                     self.params["offset_min"],
+                                                                     self.params["offset_max"]])
+                elif self.params["psf"] == 1:
+                    particles = pfit.frame_to_particles_3d(frame, self.params["initial_sigma"], self.params["estimator"], self.params["crop_radius"],
+                                                        constraints=[self.params["intensity_min"],
+                                                                     self.params["intensity_max"], -1, -1, -1, -1,
+                                                                     self.params["sigma_min"],
+                                                                     self.params["sigma_max"],
+                                                                     self.params["sigma_min"],
+                                                                     self.params["sigma_max"],
+                                                                     self.params["offset_min"],
+                                                                     self.params["offset_max"]])
             elif self.params["estimator"] == 2:
-                particles = list()
+                x = np.empty(len(frame.maxima))
+                y = np.empty(len(frame.maxima))
+                intensity = np.empty(len(frame.maxima))
                 pxd = frame.load()
                 for i in range(len(frame.maxima)):
-                    intensity = pxd[frame.maxima[i, 0], frame.maxima[i, 1]]
-                    x = frame.maxima[i, 1]
-                    y = frame.maxima[i, 0]
-                    particles.append(Particle(idx, x, y, 1.0, intensity))
+                    intensity[i] = pxd[frame.maxima[i, 0], frame.maxima[i, 1]]
+                    x[i] = frame.maxima[i, 1]
+                    y[i] = frame.maxima[i, 0]
+                particles = dict()
+                particles["x [nm]"] = x
+                particles["y [nm]"] = y
+                particles["intensity [counts]"] = intensity
             frame.particles = particles
             new_maxima = list()
-            for particle in frame.particles:
-                new_maxima.append([particle.y, particle.x])
+            new_maxima_x = frame.particles["x [nm]"]
+            new_maxima_y = frame.particles["y [nm]"]
+            for _x, _y in zip(new_maxima_x, new_maxima_y):
+                new_maxima.append([_y, _x])
             frame.maxima = new_maxima
             return frame
 
